# Retrieving Survey Results
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/retrieving-survey-results#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/retrieving-survey-results#prerequisites)
  * [Step 1: Get the Survey ID](https://help.sap.com/docs/leanix/ea/retrieving-survey-results#step-1:-get-the-survey-id)
  * [Step 2: Get the Survey Run ID](https://help.sap.com/docs/leanix/ea/retrieving-survey-results#step-2:-get-the-survey-run-id)
  * [Step 3: Get Survey Results](https://help.sap.com/docs/leanix/ea/retrieving-survey-results#step-3:-get-survey-results)


Retrieve survey results using the Survey REST API.
